/*
 * @Author: Kane
 * @Date: 2023-02-28 09:26:45
 * @LastEditors: Kane
 * @FilePath: /task_schedule/src/utils/api/localStorage.ts
 * @Description:
 *
 * Copyright (c) ${2022} by Kane, All Rights Reserved.
 */
import { StaffInfo } from "@/data/cpicxim/StaffInfo.js";

const STUFF_ITEM = "stuff_info";
const CALLER_ITEM = "call_info";
const USER_TYPE_ITEM = "user_type";

function loadStaffInfo(): StaffInfo
{
    let obj = null;

    try
    {
        obj = JSON.parse( window.localStorage.getItem( STUFF_ITEM ) ?? "{}" );
    }
    catch ( error )
    {
        obj = {};
    }

    const stuff = new StaffInfo(
        obj._p13uid ?? "",
        obj._stuffCode ?? "",
        obj._stuffName ?? "",
        obj._department_code ?? "",
        obj._department_name ?? "",
        obj._section_office_code ?? "",
        obj._section_office_name ?? "" );

    return stuff;
}

function saveStaffInfo( stuff: StaffInfo ): void
{
    const json = JSON.stringify( stuff );

    window.localStorage.setItem( STUFF_ITEM, json );
};

function cleanStaffInfo(): void
{
    window.localStorage.removeItem( STUFF_ITEM );
}

function saveUserType( userType: string ): void
{
    window.localStorage.setItem( USER_TYPE_ITEM, userType );
}

function getUserType(): string
{
    const userType = window.localStorage.getItem( USER_TYPE_ITEM ) ?? "";

    return userType;
}

function saveCallerInfo( callerCode: string ): void
{
    window.localStorage.setItem( CALLER_ITEM, callerCode );
}

function getCallerInfo(): string
{
    return window.localStorage.getItem( CALLER_ITEM ) ?? "";
}

function clearCallerInfo(): void
{
    window.localStorage.removeItem( CALLER_ITEM );
}

export {
    loadStaffInfo,
    saveStaffInfo,
    cleanStaffInfo,
    saveUserType,
    getUserType,
    saveCallerInfo,
    getCallerInfo,
    clearCallerInfo
};
